@@ -4,7 +4,7 @@
 
 #include "backend.h"
 
-static char *types[64];
+static const char *types[64];
 
 static struct bed_list_st {
   Rcairo_backend_def* bed;
@@ -24,8 +24,8 @@ void Rcairo_register_backend(Rcairo_backend_def* def) {
   }
   l->bed = def;
   { /* collect types list */
-    char **c = types;
-    char **d = def->types;
+    const char **c = types;
+    const char **d = def->types;
     while (*c) c++;
     while (*d) {
       *c=*d; c++; d++;
@@ -34,8 +34,8 @@ void Rcairo_register_backend(Rcairo_backend_def* def) {
   }
 }
 
-int Rcairo_type_supported(char *type) {
-  char **c = types;
+int Rcairo_type_supported(const char *type) {
+  const char **c = types;
   if (!type) return 0;
   while (*c) {
     if (!strcmp(type, *c)) return 1;
@@ -44,17 +44,33 @@ int Rcairo_type_supported(char *type) {
   return 0;
 }
 
+/* for additional capabilities */
+#include "cairogd.h"
+
 SEXP Rcairo_supported_types() {
-  char **c = types;
+  const char **c = types;
   int i = 0;
   SEXP res;
   while (*c) { c++; i++; }
+  /* we also add general capabilities: freetype and harfbuzz */
+#if USE_CAIRO_FT
+  i++;
+#ifdef HAVE_HARFBUZZ
+  i++;
+#endif
+#endif
   PROTECT(res=allocVector(STRSXP, i));
   i = 0; c = types;
   while (*c) {
-    SET_VECTOR_ELT(res, i, mkChar(*c));
+    SET_STRING_ELT(res, i, mkChar(*c));
     c++; i++;
   }
+#if USE_CAIRO_FT
+  SET_STRING_ELT(res, i++, mkChar("freetype"));
+#ifdef HAVE_HARFBUZZ
+  SET_STRING_ELT(res, i++, mkChar("harfbuzz"));
+#endif
+#endif
   UNPROTECT(1);
   return res;
 }
